"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildUrl = exports.normalize = exports.validate = void 0;
const ORCID_REGEX_STRICT = '^([0-9]{4}-){3}[0-9]{3}[0-9X]$';
const ORCID_REGEX = '^(http(s)?://(www.)?orcid.org/)?([0-9]{4}-){3}[0-9]{3}[0-9X]$';
/**
 * Validate that the input string is valid.
 *
 * @param value
 * @returns true if ORCID is valid
 */
function validate(value, opts) {
    const match = value === null || value === void 0 ? void 0 : value.match((opts === null || opts === void 0 ? void 0 : opts.strict) ? ORCID_REGEX_STRICT : ORCID_REGEX);
    if (!match)
        return false;
    return true;
}
exports.validate = validate;
/**
 * Normalize an input string to the ID part of an ORCID
 *
 * @param value
 * @returns a string if it is valid of the form 0000-0002-7859-8394
 */
function normalize(value, opts) {
    if (!value || !validate(value, opts))
        return undefined;
    return value.replace(/^https?:\/\/(www\.)?orcid\.org\//, '');
}
exports.normalize = normalize;
/**
 * Builds a canonical URL pointing to https://orcid.org
 *
 * @param value
 * @returns the orcid as a url
 */
function buildUrl(value, opts) {
    const orcid = normalize(value, opts);
    if (!orcid)
        return undefined;
    return `https://orcid.org/${orcid}`;
}
exports.buildUrl = buildUrl;
exports.default = {
    validate,
    normalize,
    buildUrl,
};
